# Rachis Framework (Formerly Known as QIIME 2 Framework (Q2F))

![](https://github.com/qiime2/qiime2/workflows/ci-dev/badge.svg)

Source code repository for the QIIME 2™ Framework.

Are you looking for:
- the QIIME 2 homepage? That's [https://qiime2.org](https://qiime2.org).
- learning resources for microbiome marker gene (i.e., amplicon) analysis? See the [QIIME 2 *amplicon distribution* documentation](https://amplicon-docs.readthedocs.io).
- learning resources for microbiome metagenome analysis? See the [MOSHPIT documentation](https://moshpit.readthedocs.io).
- installation instructions, plugins, books, videos, workshops, or resources? See the [QIIME 2 Library](https://library.qiime2.org).
- general help? See the [QIIME 2 Forum](https://forum.qiime2.org)
- information about contributing? See the [Contributing Guide](https://github.com/qiime2/.github/blob/main/CONTRIBUTING.md).
- information about the developers? See the [Caporaso Lab website](https://caplab.bio).

## Citing QIIME 2

If you use QIIME 2 for any published research, please cite [Bolyen, Rideout, Dillon, Bokulich, et al. (2019)](https://doi.org/10.1038/s41587-019-0209-9).
